controller

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 13, 2026 License: Apache-2.0 Imports: 44 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type FabricNetworkReconciler

type FabricNetworkReconciler struct {
	client.Client
	Scheme   *runtime.Scheme
	Recorder record.EventRecorder
}

FabricNetworkReconciler reconciles a FabricNetwork object

func (*FabricNetworkReconciler) Reconcile

func (r *FabricNetworkReconciler) Reconcile(ctx context.Context, req ctrl.Request) (ctrl.Result, error)

Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state.

func (*FabricNetworkReconciler) SetupWithManager

func (r *FabricNetworkReconciler) SetupWithManager(mgr ctrl.Manager) error

SetupWithManager sets up the controller with the Manager.

type FabricParticipantReconciler

type FabricParticipantReconciler struct {
	client.Client
	Scheme *runtime.Scheme
}

FabricParticipantReconciler reconciles a FabricParticipant object

func (*FabricParticipantReconciler) Reconcile

Reconcile validates the participant join contract, reconciles the local org infrastructure, and advances participant-side channel joins when imported artifacts are available.

func (*FabricParticipantReconciler) SetupWithManager

func (r *FabricParticipantReconciler) SetupWithManager(mgr ctrl.Manager) error

SetupWithManager sets up the controller with the Manager.

Jump to