Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type FabricNetworkReconciler ¶
type FabricNetworkReconciler struct {
client.Client
Scheme *runtime.Scheme
Recorder record.EventRecorder
}
FabricNetworkReconciler reconciles a FabricNetwork object
func (*FabricNetworkReconciler) Reconcile ¶
func (r *FabricNetworkReconciler) Reconcile(ctx context.Context, req ctrl.Request) (ctrl.Result, error)
Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state.
func (*FabricNetworkReconciler) SetupWithManager ¶
func (r *FabricNetworkReconciler) SetupWithManager(mgr ctrl.Manager) error
SetupWithManager sets up the controller with the Manager.
type FabricParticipantReconciler ¶
FabricParticipantReconciler reconciles a FabricParticipant object
func (*FabricParticipantReconciler) Reconcile ¶
func (r *FabricParticipantReconciler) Reconcile(ctx context.Context, req ctrl.Request) (ctrl.Result, error)
Reconcile validates the participant join contract, reconciles the local org infrastructure, and advances participant-side channel joins when imported artifacts are available.
func (*FabricParticipantReconciler) SetupWithManager ¶
func (r *FabricParticipantReconciler) SetupWithManager(mgr ctrl.Manager) error
SetupWithManager sets up the controller with the Manager.
Source Files
¶
- fabricnetwork_chaincode.go
- fabricnetwork_channel.go
- fabricnetwork_connection_profile.go
- fabricnetwork_controller.go
- fabricnetwork_endpoint_status.go
- fabricnetwork_enrollment.go
- fabricnetwork_external_endpoint.go
- fabricnetwork_external_org.go
- fabricnetwork_identity.go
- fabricnetwork_job_cleanup.go
- fabricnetwork_org.go
- fabricnetwork_topology.go
- fabricparticipant_chaincode.go
- fabricparticipant_channel.go
- fabricparticipant_controller.go
- fabricparticipant_topology.go
Click to show internal directories.
Click to hide internal directories.